==> pmudmon-0.2.tar.gz: pmudmon-0.2/conf.c <==
/* pmudmon applet
 *** Copyright (C) 2000 Mike Palczewski mpalczew@u.washington.edu
 *** 
 *** This program is free software; you can redistribute it and/or
 *** modify it under the terms of the GNU General Public License
 *** as published by the Free Software Foundation; either version 2
 *** of the License, or (at your option) any later version.
 *** 
 *** This program is distributed in the hope that it will be useful,
 *** but WITHOUT ANY WARRANTY; without even the implied warranty of
 *** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *** GNU General Public License for more details.
 *** 
 *** You should have received a copy of the GNU General Public License
 *** along with this program; if not, write to the Free Software
 *** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
 *** 02111-1307, USA.
 ***/

#include "conf.h"
#include "main.h"

conf* get_conf() {
	conf* l;
	l=malloc(sizeof(conf));
	
	l->height=gnome_config_get_int("/pmudmon/main/height=24");
	l->width=gnome_config_get_int("/pmudmon/main/width=150");
	l->time=gnome_config_get_int("/pmudmon/main/time=10");
	l->orientation=gnome_config_get_int("/pmudmon/main/orientation=0");
	l->format_charging=gnome_config_get_string("/pmudmon/main/charging=AC Charging");
	l->format_battery=gnome_config_get_string("/pmudmon/main/battery=Battery");
	l->format_charged=gnome_config_get_string("/pmudmon/main/charged=AC Charged");
	return l;
}



void set_conf(conf* config) {
	gnome_config_set_int("/pmudmon/main/height",config->height);
	gnome_config_set_int("/pmudmon/main/width",config->width);
	gnome_config_set_int("/pmudmon/main/orientation",config->orientation);
	gnome_config_set_int("/pmudmon/main/time",config->time);
	
	if (config->format_charging)
		gnome_config_set_string("/pmudmon/main/charging",config->format_charging);
	if (config->format_battery)
		gnome_config_set_string("/pmudmon/main/battery",config->format_battery);
	if (config->format_charged)
		gnome_config_set_string("/pmudmon/main/charged",config->format_charged);
	gnome_config_sync();
}


void free_conf(conf* config) {
	if (config->format_charging)
		g_free(config->format_charging);
	if (config->format_battery)
		g_free(config->format_battery);
	if (config->format_charged)
		g_free(config->format_charged);
	free(config);
}

==> pmudmon-0.3.tar.gz: pmudmon-0.3/conf.c <==
/* pmudmon applet
 *** Copyright (C) 2000 Mike Palczewski mpalczew@u.washington.edu
 *** 
 *** This program is free software; you can redistribute it and/or
 *** modify it under the terms of the GNU General Public License
 *** as published by the Free Software Foundation; either version 2
 *** of the License, or (at your option) any later version.
 *** 
 *** This program is distributed in the hope that it will be useful,
 *** but WITHOUT ANY WARRANTY; without even the implied warranty of
 *** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *** GNU General Public License for more details.
 *** 
 *** You should have received a copy of the GNU General Public License
 *** along with this program; if not, write to the Free Software
 *** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
 *** 02111-1307, USA.
 ***/

#include "conf.h"
#include "main.h"

conf* get_conf() {
	conf* l;
	l=malloc(sizeof(conf));
	
	l->height=gnome_config_get_int("/pmudmon/main/height=24");
	l->width=gnome_config_get_int("/pmudmon/main/width=150");
	l->time=gnome_config_get_int("/pmudmon/main/time=10");
	l->orientation=gnome_config_get_int("/pmudmon/main/orientation=0");
	l->format_charging=gnome_config_get_string("/pmudmon/main/charging=AC Charging%p%%");
	l->format_battery=gnome_config_get_string("/pmudmon/main/battery=Battery %p%%");
	l->format_charged=gnome_config_get_string("/pmudmon/main/charged=AC Charged %p%%");
	return l;
}



void set_conf(conf* config) {
	gnome_config_set_int("/pmudmon/main/height",config->height);
	gnome_config_set_int("/pmudmon/main/width",config->width);
	gnome_config_set_int("/pmudmon/main/orientation",config->orientation);
	gnome_config_set_int("/pmudmon/main/time",config->time);
	
	if (config->format_charging)
		gnome_config_set_string("/pmudmon/main/charging",config->format_charging);
	if (config->format_battery)
		gnome_config_set_string("/pmudmon/main/battery",config->format_battery);
	if (config->format_charged)
		gnome_config_set_string("/pmudmon/main/charged",config->format_charged);
	gnome_config_sync();
}


void free_conf(conf* config) {
	if (config->format_charging)
		g_free(config->format_charging);
	if (config->format_battery)
		g_free(config->format_battery);
	if (config->format_charged)
		g_free(config->format_charged);
	free(config);
}
